<?php
/**
 * FrozrDash back compat functionality
 *
 * Prevents FrozrDash from running on WordPress versions prior to 4.1,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.1.
 *
 * @package WordPress
 * @subpackage FrozrDash
 * @since FrozrDash 1.0
 */

/**
 * Prevent switching to FrozrDash on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since FrozrDash 1.0
 */
function frozr_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'frozr_upgrade_notice' );
}
add_action( 'after_switch_theme', 'frozr_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * FrozrDash on WordPress versions prior to 4.1.
 *
 * @since FrozrDash 1.0
 */
function frozr_upgrade_notice() {
	$message = sprintf( __( 'FrozrDash requires at least WordPress version 4.1. You are running version %s. Please upgrade and try again.', 'frozrdash' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevent the Customizer from being loaded on WordPress versions prior to 4.1.
 *
 * @since FrozrDash 1.0
 */
function frozr_customize() {
	wp_die( sprintf( __( 'FrozrDash requires at least WordPress version 4.1. You are running version %s. Please upgrade and try again.', 'frozrdash' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'frozr_customize' );

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 4.1.
 *
 * @since FrozrDash 1.0
 */
function frozr_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'FrozrDash requires at least WordPress version 4.1. You are running version %s. Please upgrade and try again.', 'frozrdash' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'frozr_preview' );
