/* global colorScheme, Color */
/**
 * Add a listener to the Color Scheme control to update other color controls to new values/defaults.
 * Also trigger an update of the Color Scheme CSS when a color is changed.
 */

( function( api ) {
	var cssTemplate = wp.template( 'frozr-color-scheme' ),
		colorSchemeKeys = [
			'background_color',
			'header_background_color',
			'sidebar_background_color',
			'box_background_color',
			'textcolor',
			'sidebar_textcolor',
			'frozrdash_header_textcolor',
			'top_nav_background_color',
			'top_nav_textcolor',
			'fro_secnd_btn_color',
			'fro_secnd_btn_textcolor',
			'fro_filters_btn_color',
			'fro_filters_btn_textcolor',
		],
		colorSettings = [
			'background_color',
			'header_background_color',
			'sidebar_background_color',
			'sidebar_textcolor',
			'frozrdash_header_textcolor',
			'top_nav_background_color',
			'top_nav_textcolor',
			'fro_secnd_btn_color',
			'fro_secnd_btn_textcolor',
			'fro_filters_btn_color',
			'fro_filters_btn_textcolor',
		];

	api.controlConstructor.select = api.Control.extend( {
		ready: function() {
			if ( 'color_scheme' === this.id ) {
				this.setting.bind( 'change', function( value ) {
					// Update Background Color.
					api( 'background_color' ).set( colorScheme[value].colors[0] );
					api.control( 'background_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[0] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[0] );

					// Update Header Background Color.
					api( 'header_background_color' ).set( colorScheme[value].colors[1] );
					api.control( 'header_background_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[1] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[1] );

					// Update Header Text Color.
					api( 'frozrdash_header_textcolor' ).set( colorScheme[value].colors[6] );
					api.control( 'frozrdash_header_textcolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[6] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[6] );

					// Update Sidebar Background Color.
					api( 'sidebar_background_color' ).set( colorScheme[value].colors[2] );
					api.control( 'sidebar_background_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[2] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[2] );
					
					// Update Sidebar Text Color.
					api( 'sidebar_textcolor' ).set( colorScheme[value].colors[5] );
					api.control( 'sidebar_textcolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[5] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[5] );
					
					// Update Top Nav Background Color.
					api( 'top_nav_background_color' ).set( colorScheme[value].colors[7] );
					api.control( 'top_nav_background_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[7] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[7] );
					
					// Update Header Text Color.
					api( 'top_nav_textcolor' ).set( colorScheme[value].colors[8] );
					api.control( 'top_nav_textcolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[8] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[8] );
	
					// Update secondary buttons Color.
					api( 'fro_secnd_btn_color' ).set( colorScheme[value].colors[9] );
					api.control( 'fro_secnd_btn_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[9] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[9] );
						
					// Update secondary buttons Text Color.
					api( 'fro_secnd_btn_textcolor' ).set( colorScheme[value].colors[10] );
					api.control( 'fro_secnd_btn_textcolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[10] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[10] );
						
					// Update filters buttons Color.
					api( 'fro_filters_btn_color' ).set( colorScheme[value].colors[11] );
					api.control( 'fro_filters_btn_color' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[11] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[11] );
						
					// Update filters buttons Text Color.
					api( 'fro_filters_btn_textcolor' ).set( colorScheme[value].colors[12] );
					api.control( 'fro_filters_btn_textcolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', colorScheme[value].colors[12] )
						.wpColorPicker( 'defaultColor', colorScheme[value].colors[12] );
				} );
			}
		}
	} );

	// Generate the CSS for the current Color Scheme.
	function updateCSS() {
		var scheme = api( 'color_scheme' )(), css,
			colors = _.object( colorSchemeKeys, colorScheme[ scheme ].colors );

		// Merge in color scheme overrides.
		_.each( colorSettings, function( setting ) {
			colors[ setting ] = api( setting )();
		});

		// Add additional colors.
		colors.secondary_textcolor = Color( colors.textcolor ).toCSS( 'rgba', 0.7 );
		colors.border_color = Color( colors.textcolor ).toCSS( 'rgba', 0.1 );
		colors.border_focus_color = Color( colors.textcolor ).toCSS( 'rgba', 0.3 );
		colors.secondary_sidebar_textcolor = Color( colors.sidebar_textcolor ).toCSS( 'rgba', 0.7 );
		colors.sidebar_border_color = Color( colors.sidebar_textcolor ).toCSS( 'rgba', 0.1 );
		colors.sidebar_border_focus_color = Color( colors.sidebar_textcolor ).toCSS( 'rgba', 0.3 );

		css = cssTemplate( colors );

		api.previewer.send( 'update-color-scheme-css', css );
	}

	// Update the CSS whenever a color setting is changed.
	_.each( colorSettings, function( setting ) {
		api( setting, function( setting ) {
			setting.bind( updateCSS );
		} );
	} );
	
	api.bind( 'ready', function() {
	// Detect when the preload section is expanded (or closed) so we can adjust the preview accordingly.
	api.section( 'frozr_preloader', function( section ) {
		section.expanded.bind( function( isExpanding ) {

			// Value of isExpanding will = true if you're entering the section, false if you're leaving it.
			api.previewer.send( 'frozr-preload-highlight', { expanded: isExpanding });
		});
	});
	});
} )( wp.customize );